==> webkit2gtk_2.16.3.orig.tar.xz: webkitgtk-2.16.3/Source/WebCore/loader/cache/CachedResourceClientWalker.h <==
/*
    Copyright (C) 1998 Lars Knoll (knoll@mpi-hd.mpg.de)
    Copyright (C) 2001 Dirk Mueller <mueller@kde.org>
    Copyright (C) 2004, 2005, 2006, 2007 Apple Inc. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

    This class provides all functionality needed for loading images, style sheets and html
    pages from the web. It has a memory cache for these objects.
*/

#pragma once

#include "CachedResourceClient.h"
#include <wtf/HashCountedSet.h>
#include <wtf/Vector.h>

namespace WebCore {

// Call this "walker" instead of iterator so people won't expect Qt or STL-style iterator interface.
// Just keep calling next() on this. It's safe from deletions of items.
template<typename T> class CachedResourceClientWalker {
public:
    CachedResourceClientWalker(const HashCountedSet<CachedResourceClient*>& set)
        : m_clientSet(set), m_clientVector(set.size()), m_index(0)
    {
        typedef HashCountedSet<CachedResourceClient*>::const_iterator Iterator;
        Iterator end = set.end();
        size_t clientIndex = 0;
        for (Iterator current = set.begin(); current != end; ++current)
            m_clientVector[clientIndex++] = current->key;
    }

    T* next()
    {
        size_t size = m_clientVector.size();
        while (m_index < size) {
            CachedResourceClient* next = m_clientVector[m_index++];
            if (m_clientSet.contains(next)) {
                ASSERT_WITH_SECURITY_IMPLICATION(T::expectedType() == CachedResourceClient::expectedType() || next->resourceClientType() == T::expectedType());
                return static_cast<T*>(next);
            }
        }
        
        return nullptr;
    }
private:
    const HashCountedSet<CachedResourceClient*>& m_clientSet;
    Vector<CachedResourceClient*> m_clientVector;
    size_t m_index;
};

} // namespace WebCore

==> webkit2gtk_2.18.0.orig.tar.xz: webkitgtk-2.18.0/Source/WebCore/loader/cache/CachedResourceClientWalker.h <==
/*
    Copyright (C) 1998 Lars Knoll (knoll@mpi-hd.mpg.de)
    Copyright (C) 2001 Dirk Mueller <mueller@kde.org>
    Copyright (C) 2004, 2005, 2006, 2007 Apple Inc. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

    This class provides all functionality needed for loading images, style sheets and html
    pages from the web. It has a memory cache for these objects.
*/

#pragma once

#include "CachedResourceClient.h"
#include <wtf/HashCountedSet.h>
#include <wtf/Vector.h>

namespace WebCore {

// Call this "walker" instead of iterator so people won't expect Qt or STL-style iterator interface.
// Just keep calling next() on this. It's safe from deletions of items.
template<typename T>
class CachedResourceClientWalker {
public:
    CachedResourceClientWalker(const HashCountedSet<CachedResourceClient*>& clientSet)
        : m_clientSet(clientSet)
        , m_clientVector(clientSet.size())
    {
        size_t clientIndex = 0;
        for (const auto& client : clientSet)
            m_clientVector[clientIndex++] = client.key;
    }

    T* next()
    {
        size_t size = m_clientVector.size();
        while (m_index < size) {
            CachedResourceClient* next = m_clientVector[m_index++];
            if (m_clientSet.contains(next)) {
                ASSERT_WITH_SECURITY_IMPLICATION(T::expectedType() == CachedResourceClient::expectedType() || next->resourceClientType() == T::expectedType());
                return static_cast<T*>(next);
            }
        }
        return nullptr;
    }
private:
    const HashCountedSet<CachedResourceClient*>& m_clientSet;
    Vector<CachedResourceClient*> m_clientVector;
    size_t m_index { 0 };
};

} // namespace WebCore
